| Title: | Sampler for Verification Studies |
|---|---|
| Description: | A binding for the 'valection' program which offers various ways to sample the outputs of competing algorithms or parameterizations, and fairly assess their performance against each other. The 'valection' C library is required to use this package and can be downloaded from: <http://labs.oicr.on.ca/boutros-lab/software/valection>. Cooper CI, et al; Valection: Design Optimization for Validation and Verification Studies; Biorxiv 2018; <doi:10.1101/254839>. |
| Authors: | Chris Cooper [aut], Dorota H. Sendorek [ctb], Paul C. Boutros [cre, cph] |
| Maintainer: | Paul C. Boutros <[email protected]> |
| License: | GPL-3 |
| Version: | 1.0.0 |
| Built: | 2026-06-03 06:59:28 UTC |
| Source: | https://github.com/cran/valection |
Runs the decreasing with overlap algorithm from the valection library.
run.decreasing.with.overlap(budget, infile, outfile, seed);run.decreasing.with.overlap(budget, infile, outfile, seed);
budget |
An integer specifying the number of candidates to select. |
infile |
Path to input file. It should be formatted with a tab separating the caller and call on each line. caller1 name a call this caller made caller2 name a call this caller made |
outfile |
Path to a filename where the calls should be outputted. |
seed |
An integer specifying the random seed value. Optional. |
Sampling calls where the likelihood of a call getting selected is inversely proportional to the number of callers that made the call.
Chris Cooper
## Not run: run.decreasing.with.overlap( budget = 5, infile = system.file("extdata/infile_example.tsv", package = "valection"), outfile = "outfile_decreasingWithOverlap.txt" ); ## End(Not run)## Not run: run.decreasing.with.overlap( budget = 5, infile = system.file("extdata/infile_example.tsv", package = "valection"), outfile = "outfile_decreasingWithOverlap.txt" ); ## End(Not run)
Runs the directed sampling algorithm from the valection library.
run.directed.sampling(budget, infile, outfile, seed);run.directed.sampling(budget, infile, outfile, seed);
budget |
An integer specifying the number of candidates to select. |
infile |
Path to input file. It should be formatted with a tab separating the caller and call on each line. caller1 name a call this caller made caller2 name a call this caller made |
outfile |
Path to a filename where the calls should be outputted. |
seed |
An integer specifying the random seed value. Optional. |
Sampling calls where a) an equal number of calls is selected from each caller and b) the likelihood of a call getting selected is proportional to the number of callers that made it.
Chris Cooper
## Not run: run.directed.sampling( budget = 5, infile = system.file("extdata/infile_example.tsv", package = "valection"), outfile = "outfile_directedSampling.txt" ); ## End(Not run)## Not run: run.directed.sampling( budget = 5, infile = system.file("extdata/infile_example.tsv", package = "valection"), outfile = "outfile_directedSampling.txt" ); ## End(Not run)
Runs the equal per caller algorithm from the valection library.
run.equal.per.caller(budget, infile, outfile, seed);run.equal.per.caller(budget, infile, outfile, seed);
budget |
An integer specifying the number of candidates to select. |
infile |
Path to input file. It should be formatted with a tab separating the caller and call on each line. caller1 name a call this caller made caller2 name a call this caller made |
outfile |
Path to a filename where the calls should be outputted. |
seed |
An integer specifying the random seed value. Optional. |
Sampling calls where an equal number of calls is selected from each caller.
Chris Cooper
## Not run: run.equal.per.caller( budget = 5, infile = system.file("extdata/infile_example.tsv", package = "valection"), outfile = "outfile_runEqualPerCaller.txt" ); ## End(Not run)## Not run: run.equal.per.caller( budget = 5, infile = system.file("extdata/infile_example.tsv", package = "valection"), outfile = "outfile_runEqualPerCaller.txt" ); ## End(Not run)
Runs the equal per overlap algorithm from the valection library.
run.equal.per.overlap(budget, infile, outfile, seed);run.equal.per.overlap(budget, infile, outfile, seed);
budget |
An integer specifying the number of candidates to select. |
infile |
Path to input file. It should be formatted with a tab separating the caller and call on each line. caller1 name a call this caller made caller2 name a call this caller made |
outfile |
Path to a filename where the calls should be outputted. |
seed |
An integer specifying the random seed value. Optional. |
Sampling calls by, first, grouping calls by number of callers making the call and, second, selecting an equal number of calls from each group.
Chris Cooper
## Not run: run.equal.per.overlap( budget = 5, infile = system.file("extdata/infile_example.tsv", package = "valection"), outfile = "outfile_equalPerOverlap.txt" ); ## End(Not run)## Not run: run.equal.per.overlap( budget = 5, infile = system.file("extdata/infile_example.tsv", package = "valection"), outfile = "outfile_equalPerOverlap.txt" ); ## End(Not run)
Runs the increasing with overlap algorithm from the valection library.
run.increasing.with.overlap(budget, infile, outfile, seed);run.increasing.with.overlap(budget, infile, outfile, seed);
budget |
An integer specifying the number of candidates to select. |
infile |
Path to input file. It should be formatted with a tab separating the caller and call on each line. caller1 name a call this caller made caller2 name a call this caller made |
outfile |
Path to a filename where the calls should be outputted. |
seed |
An integer specifying the random seed value. Optional. |
Sampling calls where the likelihood of a call getting selected is proportional to the number of callers that made the call.
Chris Cooper
## Not run: run.increasing.with.overlap( budget = 5, infile = system.file("extdata/infile_example.tsv", package = "valection"), outfile = "outfile_increasingWithOverlap.txt" ); ## End(Not run)## Not run: run.increasing.with.overlap( budget = 5, infile = system.file("extdata/infile_example.tsv", package = "valection"), outfile = "outfile_increasingWithOverlap.txt" ); ## End(Not run)
Runs the random sampling algorithm from the valection library.
run.random.sampling(budget, infile, outfile, seed);run.random.sampling(budget, infile, outfile, seed);
budget |
An integer specifying the number of candidates to select. |
infile |
Path to input file. It should be formatted with a tab separating the caller and call on each line. caller1 name a call this caller made caller2 name a call this caller made |
outfile |
Path to a filename where the calls should be outputted. |
seed |
An integer specifying the random seed value. Optional. |
Sampling calls randomly where each call has an equal probability of getting selected.
Chris Cooper
## Not run: run.random.sampling( budget = 5, infile = system.file("extdata/infile_example.tsv", package = "valection"), outfile = "outfile_randomSampling.txt" ); ## End(Not run)## Not run: run.random.sampling( budget = 5, infile = system.file("extdata/infile_example.tsv", package = "valection"), outfile = "outfile_randomSampling.txt" ); ## End(Not run)